package com.ynet.life.loaf;

import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.jdbc.DataTypeConfig;
import com.ynet.life.loaf.jdbc.LoafPreparedData;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/* loaded from: com_ynet_life_loaf.jar:com/ynet/life/loaf/LoafDataChangeBean.class */
public class LoafDataChangeBean {
    private static final String UPDATE_ERROR_CODE = "EBIM6010";
    private String itsTableName;
    private String itsTablePk;
    private int itsOpType;
    private Map itsFieldMap;

    /* JADX INFO: Access modifiers changed from: protected */
    public LoafDataChangeBean() {
    }

    public LoafDataChangeBean(String tableName, String tablePk, String opType) {
        this.itsTableName = tableName;
        this.itsTablePk = tablePk;
        try {
            this.itsOpType = Integer.parseInt(opType);
        } catch (NumberFormatException ex) {
            this.itsOpType = 1;
            Trace.logError("LOAF", ex.getMessage(), ex);
        }
        this.itsFieldMap = new HashMap();
    }

    public void addField(String fieldName, String fieldValue) {
        this.itsFieldMap.put(fieldName, fieldValue);
    }

    public String getTableName() {
        return this.itsTableName;
    }

    public String getTablePk() {
        return this.itsTablePk;
    }

    public Map getFieldMap() {
        return this.itsFieldMap;
    }

    public void doUpdate(Connection connection) throws TranFailException {
        PreparedStatement statement;
        if (this.itsOpType != 2 && this.itsFieldMap.size() == 0) {
            return;
        }
        try {
            try {
                if (this.itsOpType == 4) {
                    this.itsOpType = 3;
                    PreparedStatement preparedStatement = getPreparedStatement(connection);
                    statement = preparedStatement;
                    if (preparedStatement.executeUpdate() == 0) {
                        this.itsOpType = 1;
                        PreparedStatement preparedStatement2 = getPreparedStatement(connection);
                        statement = preparedStatement2;
                        preparedStatement2.executeUpdate();
                    }
                } else {
                    PreparedStatement preparedStatement3 = getPreparedStatement(connection);
                    statement = preparedStatement3;
                    preparedStatement3.executeUpdate();
                }
                LifeDBAccess.cleanResources(statement);
            } catch (SQLException se) {
                Trace.logError("LOAF", se.getMessage(), se);
                throw new TranFailException(UPDATE_ERROR_CODE, se);
            }
        } catch (Throwable th) {
            LifeDBAccess.cleanResources((PreparedStatement) null);
            throw th;
        }
    }

    private PreparedStatement getPreparedStatement(Connection connection) throws SQLException {
        StringBuffer preparedSQL = new StringBuffer();
        List inputList = new ArrayList();
        switch (this.itsOpType) {
            case LoafConstants.OP_TYPE_ADD /* 1 */:
                preparedSQL.append("INSERT INTO ").append(this.itsTableName).append("(");
                StringBuffer insertTableFields = new StringBuffer();
                StringBuffer insertValues = new StringBuffer();
                for (String tableFieldName : this.itsFieldMap.keySet()) {
                    String tableFieldValue = (String) this.itsFieldMap.get(tableFieldName);
                    if (tableFieldValue != null && !"".equals(tableFieldValue)) {
                        insertTableFields.append(tableFieldName).append(',');
                        insertValues.append("?,");
                        inputList.add(DataTypeConfig.getData(this.itsTableName, tableFieldName, tableFieldValue));
                    }
                }
                LoafTools.removeLastComma(insertTableFields);
                LoafTools.removeLastComma(insertValues);
                if (insertTableFields.length() > 0) {
                    preparedSQL.append(insertTableFields).append(")VALUES(").append(insertValues).append(")");
                    break;
                }
                break;
            case LoafConstants.OP_TYPE_DELETE /* 2 */:
                preparedSQL.append("DELETE FROM ").append(this.itsTableName).append(" WHERE ").append(this.itsTablePk);
                break;
            case LoafConstants.OP_TYPE_UPDATE /* 3 */:
                preparedSQL.append("UPDATE ").append(this.itsTableName).append(" SET ");
                for (String tableFieldName2 : this.itsFieldMap.keySet()) {
                    String tableFieldValue2 = (String) this.itsFieldMap.get(tableFieldName2);
                    preparedSQL.append(tableFieldName2).append("=");
                    if (tableFieldValue2 != null) {
                        preparedSQL.append('?');
                        inputList.add(DataTypeConfig.getData(this.itsTableName, tableFieldName2, tableFieldValue2));
                    } else {
                        preparedSQL.append("null");
                    }
                    preparedSQL.append(',');
                }
                LoafTools.removeLastComma(preparedSQL);
                preparedSQL.append(" WHERE ").append(this.itsTablePk);
                break;
        }
        PreparedStatement statement = connection.prepareStatement(preparedSQL.toString());
        Trace.logDebug("LOAF", "执行sql语句---->" + preparedSQL.toString());
        Trace.logDebug("LOAF", "输入参数列表--->".concat(String.valueOf(inputList)));
        int inputSize = inputList.size();
        for (int i = 1; i <= inputSize; i++) {
            ((LoafPreparedData) inputList.get(i - 1)).fillStatement(statement, i);
        }
        return statement;
    }

    public String toString() {
        StringBuffer result = new StringBuffer();
        result.append("Table Name:").append(this.itsTableName).append("\n");
        result.append("Table PK:").append(this.itsTablePk).append("\n");
        result.append("Operation Type:");
        switch (this.itsOpType) {
            case LoafConstants.OP_TYPE_ADD /* 1 */:
                result.append("INSERT\n");
                break;
            case LoafConstants.OP_TYPE_DELETE /* 2 */:
                result.append("DELETE\n");
                break;
            case LoafConstants.OP_TYPE_UPDATE /* 3 */:
                result.append("UPDATE\n");
                break;
        }
        return result.toString();
    }

    public int getOpType() {
        return this.itsOpType;
    }
}
